import {
  initVendorConsentsLoader,
  addVendorLoadedEventListener,
  loadComscore
} from '@adv-ui/vendor-by-consents-loader'
import getHotjarConfig from './hotjar/config'
import getOptimizelyConfig from './optimizely/config'
import getTealiumConfig from './tealium/config'
import getCriteoConfig from './criteo/config'
import getCriteoPageName from './criteo/pages'
import dispatchCriteoEvent from './criteo/events'
import getOpenAdsConfig from './openAds/config'
import getAdobeConfig from './adobe/config'

const COMSCORE_CLIENT_ID = '13013988'

const getPortal = () => {
  const match = window.location.href.match(/infojobs(\w*)\.(\w*)/)
  if (match) {
    const [, environment, portal] = match
    return {portal: portal === 'it' ? 'it' : 'es', environment}
  }
  return {portal: 'es', environment: 'qaaws'}
}

const loader = () => {
  const {portal, environment} = getPortal()
  const path = window.location.pathname
  const queryParams = window.location.search
  const {config: hotjarConfig, initScript: initHotjarScript} = getHotjarConfig({
    portal,
    path
  })
  const {config: optimizelyConfig} = getOptimizelyConfig({portal, path})

  const {config: tealiumConfig} = getTealiumConfig({
    portal,
    environment,
    queryParams
  })

  const criteoPageName = getCriteoPageName({portal, path})
  const {config: criteoConfig} = getCriteoConfig({
    criteoPageName
  })

  const {config: openAdsConfig} = getOpenAdsConfig({
    portal,
    environment,
    path
  })

  const {config: adobeConfig} = getAdobeConfig()

  initHotjarScript()

  loadComscore({comscoreClientId: COMSCORE_CLIENT_ID})

  initVendorConsentsLoader({
    vendors: {
      ...adobeConfig,
      ...tealiumConfig,
      ...openAdsConfig,
      ...optimizelyConfig,
      ...criteoConfig,
      ...hotjarConfig
    }
  })

  addVendorLoadedEventListener(({vendor}) => {
    if (vendor === 'criteo') {
      dispatchCriteoEvent({criteoPageName})
    }
  })
}

export default loader
